==> trimica-1.4.3%2B1.21.10-fabric-sources.jar: com/bawnorton/trimica/data/provider/TrimicaTrimMaterialTagProvider.java <==
package com.bawnorton.trimica.data.provider;

import com.bawnorton.bettertrims.data.TrimMaterialTags;
import com.bawnorton.trimica.data.tags.TrimicaRuntimeTags;
import com.bawnorton.trimica.extend.TagAppenderExtension;
import java.util.Comparator;
import java.util.Set;
import net.minecraft.class_11389;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_8054;

public interface TrimicaTrimMaterialTagProvider {
	default void addTags(class_7225.class_7874 wrapperLookup) {
		addItemsToTag(TrimMaterialTags.QUARTZ, Set.of(
				class_1802.field_8155,
				class_1802.field_20402,
				class_1802.field_8746,
				class_1802.field_23830,
				class_1802.field_8084,
				class_1802.field_20386,
				class_1802.field_8412,
				class_1802.field_8499,
				class_1802.field_8217,
				class_1802.field_8430,
				class_1802.field_8702
		));
		addItemsToTag(TrimMaterialTags.IRON, Set.of(
				class_1802.field_33400,
				class_1802.field_8620,
				class_1802.field_8675,
				class_1802.field_8868,
				class_1802.field_8550,
				class_1802.field_8251,
				class_1802.field_8884,
				class_1802.field_8045,
				class_1802.field_8836,
				class_1802.field_8069,
				class_1802.field_8063,
				class_1802.field_8220,
				class_1802.field_8599,
				class_1802.field_29020,
				class_1802.field_33505,
				class_1802.field_8773,
				class_1802.field_8594,
				class_1802.field_8241,
				class_1802.field_8592,
				class_1802.field_8782,
				class_1802.field_8750,
				class_1802.field_8427,
				class_1802.field_8239,
				class_1802.field_16539,
				class_1802.field_22016,
				class_1802.field_8638,
				class_1802.field_8076,
				//? if >=1.21.10 {
				class_1802.field_23983,
				//?} else {
				/*Items.CHAIN,
				*///?}
				class_1802.field_8129,
				class_1802.field_8211,
				class_1802.field_8655,
				class_1802.field_8475,
				class_1802.field_8609,
				class_1802.field_8403,
				class_1802.field_8699,
				class_1802.field_8371,
				class_1802.field_8255,
				class_1802.field_8743,
				class_1802.field_8523,
				class_1802.field_8396,
				class_1802.field_8660,
				class_1802.field_8578
		));
		addItemsToTag(TrimMaterialTags.NETHERITE, Set.of(
				class_1802.field_22018,
				class_1802.field_22020,
				class_1802.field_22025,
				class_1802.field_22026,
				class_1802.field_22024,
				class_1802.field_22023,
				class_1802.field_22022,
				class_1802.field_22027,
				class_1802.field_22028,
				class_1802.field_22029,
				class_1802.field_22030
		));
		addItemsToTag(TrimMaterialTags.REDSTONE, Set.of(
				class_1802.field_8725,
				class_1802.field_8530,
				class_1802.field_8619,
				class_1802.field_8857,
				class_1802.field_8604,
				class_1802.field_29023,
				class_1802.field_8793,
				class_1802.field_8230
		));
		addItemsToTag(TrimMaterialTags.COPPER, Set.of(
				class_1802.field_27071,
				class_1802.field_27039,
				class_1802.field_27072,
				class_1802.field_27040,
				class_1802.field_27073,
				class_1802.field_27041,
				class_1802.field_27074,
				class_1802.field_33403,
				class_1802.field_33506,
				class_1802.field_27018,
				class_1802.field_29211,
				class_1802.field_27075,
				class_1802.field_27042,
				class_1802.field_27076,
				class_1802.field_27043,
				class_1802.field_27077,
				class_1802.field_27044,
				class_1802.field_27030,
				class_1802.field_33404,
				class_1802.field_27035,
				class_1802.field_27048,
				class_1802.field_27036,
				class_1802.field_27049,
				class_1802.field_27037,
				class_1802.field_27050,
				class_1802.field_27038,
				class_1802.field_33406,
				class_1802.field_27031,
				class_1802.field_27045,
				class_1802.field_27032,
				class_1802.field_27046,
				class_1802.field_27033,
				class_1802.field_27047,
				class_1802.field_27034,
				class_1802.field_33405,
				class_1802.field_47018,
				class_1802.field_47022,
				class_1802.field_47020,
				class_1802.field_47024,
				class_1802.field_47019,
				class_1802.field_47023,
				class_1802.field_47021,
				class_1802.field_47025,
				class_1802.field_46982,
				class_1802.field_46986,
				class_1802.field_46984,
				class_1802.field_46988,
				class_1802.field_46983,
				class_1802.field_46987,
				class_1802.field_46985,
				class_1802.field_46990,
				class_1802.field_46991,
				class_1802.field_46995,
				class_1802.field_46993,
				class_1802.field_46997,
				class_1802.field_46992,
				class_1802.field_46996,
				class_1802.field_46994,
				class_1802.field_46998,
				class_1802.field_46974,
				class_1802.field_46978,
				class_1802.field_46976,
				class_1802.field_46980,
				class_1802.field_46975,
				class_1802.field_46979,
				class_1802.field_46977,
				class_1802.field_46981,
				class_1802.field_27051,
				class_1802.field_27022,
				class_1802.field_33401
				//? if >=1.21.10 {
				, class_1802.field_61303,
				class_1802.field_61307,
				class_1802.field_61305,
				class_1802.field_61309,
				class_1802.field_61304,
				class_1802.field_61308,
				class_1802.field_61306,
				class_1802.field_61310,
				class_1802.field_61334,
				class_1802.field_61332,
				class_1802.field_61336,
				class_1802.field_61331,
				class_1802.field_61335,
				class_1802.field_61333,
				class_1802.field_61337,
				class_1802.field_61311,
				class_1802.field_61315,
				class_1802.field_61313,
				class_1802.field_61317,
				class_1802.field_61312,
				class_1802.field_61316,
				class_1802.field_61314,
				class_1802.field_61318,
				class_1802.field_61900.comp_4568(),
				class_1802.field_61900.comp_4572(),
				class_1802.field_61900.comp_4570(),
				class_1802.field_61900.comp_4574(),
				class_1802.field_61900.comp_4569(),
				class_1802.field_61900.comp_4573(),
				class_1802.field_61900.comp_4571(),
				class_1802.field_61900.comp_4575(),
				class_1802.field_61899,
				class_1802.field_61897.comp_4568(),
				class_1802.field_61897.comp_4572(),
				class_1802.field_61897.comp_4570(),
				class_1802.field_61897.comp_4574(),
				class_1802.field_61897.comp_4569(),
				class_1802.field_61897.comp_4573(),
				class_1802.field_61897.comp_4571(),
				class_1802.field_61897.comp_4575(),
				class_1802.field_61898.comp_4568(),
				class_1802.field_61898.comp_4572(),
				class_1802.field_61898.comp_4570(),
				class_1802.field_61898.comp_4574(),
				class_1802.field_61898.comp_4569(),
				class_1802.field_61898.comp_4573(),
				class_1802.field_61898.comp_4571(),
				class_1802.field_61898.comp_4575(),
				class_1802.field_61349,
				class_1802.field_61343,
				class_1802.field_61344,
				class_1802.field_61345,
				class_1802.field_61346,
				class_1802.field_61341,
				class_1802.field_61342,
				class_1802.field_61340,
				class_1802.field_61339,
				class_1802.field_61338,
				class_1802.field_61348
				//?}
		));
		addItemsToTag(TrimMaterialTags.GOLD, Set.of(
				class_1802.field_33402,
				class_1802.field_8695,
				class_1802.field_8397,
				class_1802.field_8463,
				class_1802.field_8367,
				class_1802.field_8071,
				class_1802.field_8597,
				class_1802.field_8557,
				class_1802.field_8775,
				class_1802.field_29019,
				class_1802.field_23140,
				class_1802.field_23847,
				class_1802.field_33507,
				class_1802.field_8494,
				class_1802.field_16315,
				class_1802.field_8848,
				class_1802.field_8721,
				class_1802.field_8825,
				class_1802.field_8303,
				class_1802.field_8335,
				class_1802.field_8322,
				class_1802.field_8845,
				class_1802.field_8862,
				class_1802.field_8678,
				class_1802.field_8416,
				class_1802.field_8753,
				class_1802.field_8560
		));
		addItemsToTag(TrimMaterialTags.EMERALD, Set.of(
				class_1802.field_8687,
				class_1802.field_8733,
				class_1802.field_8837,
				class_1802.field_29216
		));
		addItemsToTag(TrimMaterialTags.DIAMOND, Set.of(
				class_1802.field_8477,
				class_1802.field_8603,
				class_1802.field_8787,
				class_1802.field_29022,
				class_1802.field_8556,
				class_1802.field_8527,
				class_1802.field_8377,
				class_1802.field_8250,
				class_1802.field_8802,
				class_1802.field_8805,
				class_1802.field_8058,
				class_1802.field_8348,
				class_1802.field_8285,
				class_1802.field_8807
		));
		addItemsToTag(TrimMaterialTags.LAPIS, Set.of(
				class_1802.field_8759,
				class_1802.field_8055,
				class_1802.field_8809,
				class_1802.field_29021
		));
		addItemsToTag(TrimMaterialTags.AMETHYST, Set.of(
				class_1802.field_27069,
				class_1802.field_27066,
				class_1802.field_27067,
				class_1802.field_27068,
				class_1802.field_27065,
				class_1802.field_27064,
				class_1802.field_27063
		));
		addItemsToTag(TrimMaterialTags.RESIN, Set.of(
				class_1802.field_55037,
				class_1802.field_55038,
				class_1802.field_55044,
				class_1802.field_55039,
				class_1802.field_55041,
				class_1802.field_55040,
				class_1802.field_55042,
				class_1802.field_55043
		));
	}

	@SuppressWarnings("unchecked")
	private void addItemsToTag(class_6862<class_8054> tagKey, Set<class_1792> items) {
		TagAppenderExtension<class_5321<class_8054>, class_8054> appender = (TagAppenderExtension<class_5321<class_8054>, class_8054>) builder(tagKey);
		items.stream()
				.map(class_1792::method_40131)
				.map(itemReference -> getRuntimeTags().createMaterialKeyHolderForItem(itemReference).tagKey())
				.sorted(Comparator.comparing(class_6862::comp_327))
				.forEachOrdered(appender::trimica$forceAddTag);
	}

	class_11389<class_5321<class_8054>, class_8054> builder(class_6862<class_8054> tagKey);

	TrimicaRuntimeTags getRuntimeTags();
}

==> trimica-1.4.4%2B1.21.8-fabric-sources.jar: com/bawnorton/trimica/data/provider/TrimicaTrimMaterialTagProvider.java <==
package com.bawnorton.trimica.data.provider;

import com.bawnorton.bettertrims.data.TrimMaterialTags;
import com.bawnorton.trimica.data.tags.TrimicaRuntimeTags;
import com.bawnorton.trimica.extend.TagAppenderExtension;
import java.util.Comparator;
import java.util.Set;
import net.minecraft.class_11389;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7225;
import net.minecraft.class_8054;

public interface TrimicaTrimMaterialTagProvider {
	default void addTags(class_7225.class_7874 wrapperLookup) {
		addItemsToTag(TrimMaterialTags.QUARTZ, Set.of(
				class_1802.field_8155,
				class_1802.field_20402,
				class_1802.field_8746,
				class_1802.field_23830,
				class_1802.field_8084,
				class_1802.field_20386,
				class_1802.field_8412,
				class_1802.field_8499,
				class_1802.field_8217,
				class_1802.field_8430,
				class_1802.field_8702
		));
		addItemsToTag(TrimMaterialTags.IRON, Set.of(
				class_1802.field_33400,
				class_1802.field_8620,
				class_1802.field_8675,
				class_1802.field_8868,
				class_1802.field_8550,
				class_1802.field_8251,
				class_1802.field_8884,
				class_1802.field_8045,
				class_1802.field_8836,
				class_1802.field_8069,
				class_1802.field_8063,
				class_1802.field_8220,
				class_1802.field_8599,
				class_1802.field_29020,
				class_1802.field_33505,
				class_1802.field_8773,
				class_1802.field_8594,
				class_1802.field_8241,
				class_1802.field_8592,
				class_1802.field_8782,
				class_1802.field_8750,
				class_1802.field_8427,
				class_1802.field_8239,
				class_1802.field_16539,
				class_1802.field_22016,
				class_1802.field_8638,
				class_1802.field_8076,
				//? if >=1.21.10 {
				/*Items.IRON_CHAIN,
				*///?} else {
				class_1802.field_23983,
				//?}
				class_1802.field_8129,
				class_1802.field_8211,
				class_1802.field_8655,
				class_1802.field_8475,
				class_1802.field_8609,
				class_1802.field_8403,
				class_1802.field_8699,
				class_1802.field_8371,
				class_1802.field_8255,
				class_1802.field_8743,
				class_1802.field_8523,
				class_1802.field_8396,
				class_1802.field_8660,
				class_1802.field_8578
		));
		addItemsToTag(TrimMaterialTags.NETHERITE, Set.of(
				class_1802.field_22018,
				class_1802.field_22020,
				class_1802.field_22025,
				class_1802.field_22026,
				class_1802.field_22024,
				class_1802.field_22023,
				class_1802.field_22022,
				class_1802.field_22027,
				class_1802.field_22028,
				class_1802.field_22029,
				class_1802.field_22030
		));
		addItemsToTag(TrimMaterialTags.REDSTONE, Set.of(
				class_1802.field_8725,
				class_1802.field_8530,
				class_1802.field_8619,
				class_1802.field_8857,
				class_1802.field_8604,
				class_1802.field_29023,
				class_1802.field_8793,
				class_1802.field_8230
		));
		addItemsToTag(TrimMaterialTags.COPPER, Set.of(
				class_1802.field_27071,
				class_1802.field_27039,
				class_1802.field_27072,
				class_1802.field_27040,
				class_1802.field_27073,
				class_1802.field_27041,
				class_1802.field_27074,
				class_1802.field_33403,
				class_1802.field_33506,
				class_1802.field_27018,
				class_1802.field_29211,
				class_1802.field_27075,
				class_1802.field_27042,
				class_1802.field_27076,
				class_1802.field_27043,
				class_1802.field_27077,
				class_1802.field_27044,
				class_1802.field_27030,
				class_1802.field_33404,
				class_1802.field_27035,
				class_1802.field_27048,
				class_1802.field_27036,
				class_1802.field_27049,
				class_1802.field_27037,
				class_1802.field_27050,
				class_1802.field_27038,
				class_1802.field_33406,
				class_1802.field_27031,
				class_1802.field_27045,
				class_1802.field_27032,
				class_1802.field_27046,
				class_1802.field_27033,
				class_1802.field_27047,
				class_1802.field_27034,
				class_1802.field_33405,
				class_1802.field_47018,
				class_1802.field_47022,
				class_1802.field_47020,
				class_1802.field_47024,
				class_1802.field_47019,
				class_1802.field_47023,
				class_1802.field_47021,
				class_1802.field_47025,
				class_1802.field_46982,
				class_1802.field_46986,
				class_1802.field_46984,
				class_1802.field_46988,
				class_1802.field_46983,
				class_1802.field_46987,
				class_1802.field_46985,
				class_1802.field_46990,
				class_1802.field_46991,
				class_1802.field_46995,
				class_1802.field_46993,
				class_1802.field_46997,
				class_1802.field_46992,
				class_1802.field_46996,
				class_1802.field_46994,
				class_1802.field_46998,
				class_1802.field_46974,
				class_1802.field_46978,
				class_1802.field_46976,
				class_1802.field_46980,
				class_1802.field_46975,
				class_1802.field_46979,
				class_1802.field_46977,
				class_1802.field_46981,
				class_1802.field_27051,
				class_1802.field_27022,
				class_1802.field_33401
				//? if >=1.21.10 {
				/*, Items.COPPER_CHEST,
				Items.WAXED_COPPER_CHEST,
				Items.WEATHERED_COPPER_CHEST,
				Items.WAXED_WEATHERED_COPPER_CHEST,
				Items.EXPOSED_COPPER_CHEST,
				Items.WAXED_EXPOSED_COPPER_CHEST,
				Items.OXIDIZED_COPPER_CHEST,
				Items.WAXED_OXIDIZED_COPPER_CHEST,
				Items.WAXED_LIGHTNING_ROD,
				Items.WEATHERED_LIGHTNING_ROD,
				Items.WAXED_WEATHERED_LIGHTNING_ROD,
				Items.EXPOSED_LIGHTNING_ROD,
				Items.WAXED_EXPOSED_LIGHTNING_ROD,
				Items.OXIDIZED_LIGHTNING_ROD,
				Items.WAXED_OXIDIZED_LIGHTNING_ROD,
				Items.COPPER_GOLEM_STATUE,
				Items.WAXED_COPPER_GOLEM_STATUE,
				Items.WEATHERED_COPPER_GOLEM_STATUE,
				Items.WAXED_WEATHERED_COPPER_GOLEM_STATUE,
				Items.EXPOSED_COPPER_GOLEM_STATUE,
				Items.WAXED_EXPOSED_COPPER_GOLEM_STATUE,
				Items.OXIDIZED_COPPER_GOLEM_STATUE,
				Items.WAXED_OXIDIZED_COPPER_GOLEM_STATUE,
				Items.COPPER_LANTERN.unaffected(),
				Items.COPPER_LANTERN.waxed(),
				Items.COPPER_LANTERN.weathered(),
				Items.COPPER_LANTERN.waxedWeathered(),
				Items.COPPER_LANTERN.exposed(),
				Items.COPPER_LANTERN.waxedExposed(),
				Items.COPPER_LANTERN.oxidized(),
				Items.COPPER_LANTERN.waxedOxidized(),
				Items.COPPER_TORCH,
				Items.COPPER_BARS.unaffected(),
				Items.COPPER_BARS.waxed(),
				Items.COPPER_BARS.weathered(),
				Items.COPPER_BARS.waxedWeathered(),
				Items.COPPER_BARS.exposed(),
				Items.COPPER_BARS.waxedExposed(),
				Items.COPPER_BARS.oxidized(),
				Items.COPPER_BARS.waxedOxidized(),
				Items.COPPER_CHAIN.unaffected(),
				Items.COPPER_CHAIN.waxed(),
				Items.COPPER_CHAIN.weathered(),
				Items.COPPER_CHAIN.waxedWeathered(),
				Items.COPPER_CHAIN.exposed(),
				Items.COPPER_CHAIN.waxedExposed(),
				Items.COPPER_CHAIN.oxidized(),
				Items.COPPER_CHAIN.waxedOxidized(),
				Items.COPPER_NUGGET,
				Items.COPPER_HELMET,
				Items.COPPER_CHESTPLATE,
				Items.COPPER_LEGGINGS,
				Items.COPPER_BOOTS,
				Items.COPPER_AXE,
				Items.COPPER_HOE,
				Items.COPPER_PICKAXE,
				Items.COPPER_SHOVEL,
				Items.COPPER_SWORD,
				Items.COPPER_HORSE_ARMOR
				*///?}
		));
		addItemsToTag(TrimMaterialTags.GOLD, Set.of(
				class_1802.field_33402,
				class_1802.field_8695,
				class_1802.field_8397,
				class_1802.field_8463,
				class_1802.field_8367,
				class_1802.field_8071,
				class_1802.field_8597,
				class_1802.field_8557,
				class_1802.field_8775,
				class_1802.field_29019,
				class_1802.field_23140,
				class_1802.field_23847,
				class_1802.field_33507,
				class_1802.field_8494,
				class_1802.field_16315,
				class_1802.field_8848,
				class_1802.field_8721,
				class_1802.field_8825,
				class_1802.field_8303,
				class_1802.field_8335,
				class_1802.field_8322,
				class_1802.field_8845,
				class_1802.field_8862,
				class_1802.field_8678,
				class_1802.field_8416,
				class_1802.field_8753,
				class_1802.field_8560
		));
		addItemsToTag(TrimMaterialTags.EMERALD, Set.of(
				class_1802.field_8687,
				class_1802.field_8733,
				class_1802.field_8837,
				class_1802.field_29216
		));
		addItemsToTag(TrimMaterialTags.DIAMOND, Set.of(
				class_1802.field_8477,
				class_1802.field_8603,
				class_1802.field_8787,
				class_1802.field_29022,
				class_1802.field_8556,
				class_1802.field_8527,
				class_1802.field_8377,
				class_1802.field_8250,
				class_1802.field_8802,
				class_1802.field_8805,
				class_1802.field_8058,
				class_1802.field_8348,
				class_1802.field_8285,
				class_1802.field_8807
		));
		addItemsToTag(TrimMaterialTags.LAPIS, Set.of(
				class_1802.field_8759,
				class_1802.field_8055,
				class_1802.field_8809,
				class_1802.field_29021
		));
		addItemsToTag(TrimMaterialTags.AMETHYST, Set.of(
				class_1802.field_27069,
				class_1802.field_27066,
				class_1802.field_27067,
				class_1802.field_27068,
				class_1802.field_27065,
				class_1802.field_27064,
				class_1802.field_27063
		));
		addItemsToTag(TrimMaterialTags.RESIN, Set.of(
				class_1802.field_55037,
				class_1802.field_55038,
				class_1802.field_55044,
				class_1802.field_55039,
				class_1802.field_55041,
				class_1802.field_55040,
				class_1802.field_55042,
				class_1802.field_55043
		));
	}

	@SuppressWarnings("unchecked")
	private void addItemsToTag(class_6862<class_8054> tagKey, Set<class_1792> items) {
		TagAppenderExtension<class_5321<class_8054>, class_8054> appender = (TagAppenderExtension<class_5321<class_8054>, class_8054>) builder(tagKey);
		items.stream()
				.map(class_1792::method_40131)
				.map(itemReference -> getRuntimeTags().createMaterialKeyHolderForItem(itemReference).tagKey())
				.sorted(Comparator.comparing(class_6862::comp_327))
				.forEachOrdered(appender::trimica$forceAddTag);
	}

	class_11389<class_5321<class_8054>, class_8054> builder(class_6862<class_8054> tagKey);

	TrimicaRuntimeTags getRuntimeTags();
}
